A summary object is a list, comprising three elements:
shortenedBoolean, with TRUE meaning that the middle
section of the matrix is ommitted, and FALSE meaning that the
entire matrix is returned because n is too big
nNumber of columns to return at the start and the end of the matrix
outMatrix returned: just the first and last n columns
(if shortened is TRUE), or the whole matrix if not